Root class

Constructors

Root({required String id, required int type, required List<String>? appComponentIds, required String name, required UITrigger? uiTrigger, required RootProps? props, required List<UIComponent> widgets})
Root.fromJson(Map<String, dynamic> json)
factory

Properties

appComponentIds List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
props RootProps?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int
final
uiTrigger UITrigger?
final
widgets List<UIComponent>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited