Task class

Constructors

Task({required String? id, required Map<String, dynamic>? vars, required int? status, required int? type, required List<Variant> variants, required List<Map<String, dynamic>?> data})
Task.fromJson(Map<String, dynamic> json)
factory

Properties

data List<Map<String, dynamic>?>
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int?
final
type int?
final
variants List<Variant>
final
vars Map<String, dynamic>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited